@@ -20,7 +20,7 @@ if (toupper(doc) == "COPYRIGHT")
     system(paste(getOption("pager"), doc, "&"))
   }
 }
-if (doc == "hsdar-intro.pdf")
+if (doc == "Hsdar-intro.pdf")
 {
   doc <- file.path(system.file(package = "hsdar"), "doc", doc) 
   if (.Platform$OS.type == "windows")
